%define aurox_ver 11.1
%define rel 2

Summary: The Linux kernel (the core of the Linux operating system)

# What parts do we want to build?  We must build at least one kernel.
# These are the kernels that are built IF the architecture allows it.

%define buildup 1
%define buildsmp 1
%define includexen 0
%define builddoc 0

# Versions of various parts

#
# Polite request for people who spin their own kernel rpms:
# please modify the "release" field in a way that identifies
# that the kernel isn't the stock distribution kernel, for example by
# adding some text to the end of the version number.
#
%define sublevel 14
%define kversion 2.6.%{sublevel}
%define rpmversion 2.6.%{sublevel}
%define rhbsys  %([ -r /etc/beehive-root -o -n "%{?__beehive_build}" ] && echo || echo .`whoami`)
%define release %{aurox_ver}.aur.%{rel}
%define signmodules 0
%define make_target bzImage

%define KVERREL %{PACKAGE_VERSION}-%{PACKAGE_RELEASE}

# groups of related archs
%define all_x86 i586 i686 athlon

# Override generic defaults with per-arch defaults 

%ifarch noarch
%define builddoc 1
%define buildup 0
%define buildsmp 0
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-*.config
%endif

# Second, per-architecture exclusions (ifarch)

%ifarch i586
%define buildsmp 0
%endif

%ifarch i686 athlon
%define buildxen %{includexen}
%else
%define buildxen 0
%endif

%ifarch %{all_x86}
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-i?86*.config $RPM_SOURCE_DIR/kernel-%{kversion}-athlon*.config
%define image_install_path boot
%define signmodules 0
%endif

%ifarch x86_64
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-x86_64*.config
%define image_install_path boot
%define signmodules 0
%endif

#
# Three sets of minimum package version requirements in the form of Conflicts:
# to versions below the minimum
#

#
# First the general kernel 2.6 required versions as per
# Documentation/Changes
#
%define kernel_dot_org_conflicts  ppp <= 2.3.15, pcmcia-cs <= 3.1.20, isdn4k-utils <= 3.0, mount < 2.10r-5, nfs-utils < 1.0.3, e2fsprogs < 1.29, util-linux < 2.10, jfsutils < 1.0.14, reiserfsprogs < 3.6.3, xfsprogs < 2.1.0, procps < 2.0.9, oprofile < 0.5.3

# 
# Then a series of requirements that are distribution specific, either 
# because we add patches for something, or the older versions have 
# problems with the newer kernel or lack certain things that make 
# integration in the distro harder than needed.
#
%define package_conflicts  cipe < 1.4.5, kudzu <= 0.92, initscripts < 7.23, dev < 3.2-7, iptables < 1.2.5-3, bcm5820 < 1.81, nvidia-rh72 <= 1.0 selinux-policy-targeted < 1.23.16-1

#
# Several packages had bugs in them that became obvious when the NPTL
# threading code got integrated. 
#
%define nptl_conflicts SysVinit < 2.84-13, pam < 0.75-48, vixie-cron < 3.0.1-73, privoxy < 3.0.0-8, spamassassin < 2.44-4.8.x,  cups < 1.1.17-13

#
# The ld.so.conf.d file we install uses syntax older ldconfig's don't grok.
#
%define xen_conflicts glibc < 2.3.5-1

#
# Packages that need to be installed before the kernel is, because the %post
# scripts use them.
#
%define kernel_prereq  fileutils, module-init-tools, initscripts >= 5.83, mkinitrd >= 4.2.15-1

Name: kernel
Group: System Environment/Kernel
License: GPLv2
Version: %{rpmversion}
Release: %{release}
ExclusiveArch: noarch %{all_x86} x86_64
ExclusiveOS: Linux
Provides: kernel = %{version}
Provides: kernel-drm = 4.3.0
Provides: kernel-%{_target_cpu} = %{rpmversion}-%{release}
Provides: alsa-driver
Obsoletes: alsa-driver
Provides: kernel-module-alsa
Provides: kernel-ntfs
Provides: eagle-usb-kernel
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
Conflicts: %{nptl_conflicts}
# We can't let RPM do the dependencies automatic because it'll then pick up
# a correct but undesirable perl dependency from the module headers which
# isn't required for the kernel proper to function
AutoReqProv: no

#
# List the packages used during the kernel build
#
BuildPreReq: module-init-tools, patch >= 2.5.4, bash >= 2.03, sh-utils, tar
BuildPreReq: bzip2, findutils, gzip, m4, perl, make >= 3.78, gnupg, diffutils
BuildRequires: gcc >= 3.4.2, binutils >= 2.12, redhat-rpm-config
BuildConflicts: rhbuildsys(DiskFree) < 500Mb


Source0: ftp://ftp.kernel.org/pub/linux/kernel/v2.6/linux-%{kversion}.tar.bz2

Source10: COPYING.modules
%if %{signmodules}
Source11: genkey
%endif

Source20: kernel-%{kversion}-i586.config
Source21: kernel-%{kversion}-i686.config
Source22: kernel-%{kversion}-i686-smp.config
Source23: kernel-%{kversion}-athlon.config
Source24: kernel-%{kversion}-athlon-smp.config

# Not supported:
#Source25: kernel-%{kversion}-x86_64.config
#Source26: kernel-%{kversion}-x86_64-smp.config

%if %{includexen}
Source35: kernel-%{kversion}-i686-xen0.config
Source36: kernel-%{kversion}-i686-xenU.config
%endif

#
# Patches 0 through 100 are meant for core subsystem upgrades
#
Patch1: patch-2.6.14.6.bz2
Patch2: linux-2.6.15-various-fixes.patch

# Patches 100 through 500 are meant for architecture patches
Patch100: linux-2.6-bzimage.patch

# 200 - 299   x86(-64)

Patch200: linux-2.6-x86-tune-p4.patch
Patch201: linux-2.6-x86-apic-off-by-default.patch
Patch202: linux-2.6-x86-vga-vidfail.patch
Patch203: linux-2.6-x86-hp-reboot.patch
Patch204: linux-2.6-x86_64-ati-apic-timer.patch

# 700 - 799 Xen
Patch700: linux-2.6-xen.patch
Patch701: linux-2.6-xen-additional.patch
Patch702: linux-2.6-xen-compile.patch

#
# Patches 800 through 899 are reserved for bugfixes to the core system
# and patches related to how RPMs are build
#
Patch800: linux-2.6-build-nonintconfig.patch
Patch801: linux-2.6-build-userspace-headers-warning.patch
Patch802: linux-2.6-build-qconfig-qt-lib64.patch
Patch803: linux-2.6-build-reference-discarded-opd.patch

# Exec-shield.
Patch810: linux-2.6-execshield.patch
Patch811: linux-2.6-execshield-xen.patch
Patch812: linux-2.6-execshield-vdso.patch
Patch813: linux-2.6-xen-vdso-note.patch
Patch814: linux-2.6-write-protect-rodata.patch


#
# Patches 1000 to 5000 are reserved for bugfixes to drivers and filesystems
#

Patch1011: linux-2.6-debug-slab-backtrace.patch
Patch1012: linux-2.6-debug-list_head.patch
Patch1013: linux-2.6-debug-taint-vm.patch
Patch1014: linux-2.6-debug-taint-check.patch
Patch1015: linux-2.6-debug-singlebiterror.patch
Patch1016: linux-2.6-debug-spinlock-taint.patch
Patch1017: linux-2.6-debug-spinlock-panic.patch
Patch1018: linux-2.6-debug-Wundef.patch
Patch1019: linux-2.6-debug-disable-builtins.patch
Patch1020: linux-2.6-debug-sleep-in-irq-warning.patch
Patch1021: linux-2.6-debug-reference-discarded-return-result.patch
Patch1022: linux-2.6-debug-panic-stackdump.patch
Patch1023: linux-2.6-debug-spinlock-emerg.patch

# Restrict /dev/mem usage.
Patch1050: linux-2.6-devmem.patch
Patch1051: linux-2.6-devmem-xen.patch

# Provide read only /dev/crash driver.
Patch1060: linux-2.6-crash-driver.patch
Patch1061: linux-2.6-crash-xen.patch

Patch1070: linux-2.6-sleepon.patch

# Tweak some defaults.
Patch1080: linux-2.6-default-elevator.patch
Patch1081: linux-2.6-max-symlinks.patch
Patch1082: linux-2.6-optimise-for-size.patch

# SCSI bits.
Patch1101: linux-2.6-scsi-advansys-enabler.patch
Patch1102: linux-2.6-scsi-megaraid-legacy.patch
Patch1103: linux-2.6-scsi-advansys-pcitable.patch
Patch1104: linux-2.6-scsi-runqueue-oops.patch

# NFS bits.
Patch1200: linux-2.6-NFSD-non-null-getxattr.patch
Patch1201: linux-2.6-NFSD-ctlbits.patch
Patch1202: linux-2.6-NFSD-locking-fix.patch
Patch1203: linux-2.6-NFSD-badness.patch

# NIC driver updates
Patch1301: linux-2.6-net-sundance-ip100A.patch
Patch1302: linux-2.6-net-atm-lanai-nodev-rmmod.patch
Patch1303: linux-2.6-net-acenic-use-after-free.patch
Patch1304: linux-2.6-net-sk98lin-vpd.patch

Patch1400: linux-2.6-pcmcia-disable-warning.patch

# Squashfs
Patch1450: linux-2.6-squashfs.patch

# Netdump and Diskdump bits.
Patch1500: linux-2.6-crashdump-common.patch
Patch1501: linux-2.6-netdump.patch
Patch1502: linux-2.6-netconsole.patch
Patch1503: linux-2.6-diskdump.patch
Patch1504: linux-2.6-crashdump-reboot-exports.patch
Patch1505: linux-2.6-dump_smp_call_function.patch

# Misc bits.
Patch1600: linux-2.6-procfs-i_nlink-miscalculate.patch
Patch1610: linux-2.6-atkbd-dell-multimedia.patch
Patch1620: linux-2.6-mcs-canonicalise-getxattr.patch
Patch1630: linux-2.6-module_version.patch
Patch1650: linux-2.6-cx88-silence-debug.patch
Patch1660: linux-2.6-swsusp-nofreeze.patch
Patch1670: linux-2.6-input-kill-stupid-messages.patch
Patch1680: linux-2.6-input-usblegacy.patch
Patch1690: linux-2.6-serial-tickle-nmi.patch
Patch1700: linux-2.6-missing-exports.patch
Patch1710: linux-2.6-radeon-backlight.patch
Patch1720: linux-2.6-ide-tune-locking.patch
Patch1730: linux-2.6-autofs-pathlookup.patch
Patch1740: linux-2.6-alsa-maestro-hang.patch
Patch1750: linux-2.6-8139too-suspend.patch
Patch1751: linux-2.6-selinux-hush.patch
Patch1753: linux-2.6-smsc-ircc2-pnp.patch
Patch1754: linux-2.6-ide-scsi-check_condition.patch
Patch1755: linux-2.6-usbhid-wireless-security-lock.patch
Patch1756: linux-2.6-net-rtnetlink-infinite-loop.patch
Patch1757: linux-2.6-w1-hush-debug.patch
Patch1758: linux-2.6-pwc-powerup-by-default.patch
#Patch1759: linux-2.6-kauditd-suspend.patch FIXME
Patch1760: linux-2.6-firmware-timeout.patch
Patch1761: linux-2.6-suspend-mxcsr.patch
Patch1771: linux-2.6-sata-promise-pata-ports.patch
Patch1782: linux-2.6-selinux-mls-compat.patch
Patch1783: linux-2.6-usbhid-wacom.patch
Patch1790: linux-2.6-block-reduce-stack.patch

# ACPI patches.
Patch1800: linux-2.6-acpi-enable-ecburst.patch
Patch1801: linux-2.6-acpi-silence-cutoff.patch
Patch1802: linux-2.6-acpi-thinkpad-c2c3.patch
Patch1803: linux-2.6-acpi-20050902.patch
Patch1804: linux-2.6-acpi-ht.patch
Patch1805: linux-2.6-acpi-owner_id-limit.patch

# Warn about usage of various obsolete functionality that may go away.
Patch1900: linux-2.6-obsolete-idescsi-warning.patch
Patch1901: linux-2.6-obsolete-oss-warning.patch

# no external module should use these symbols.
Patch1910: linux-2.6-unexport-symbols.patch


# VM bits.
Patch2000: linux-2.6-vm-oomkiller-debugging.patch
Patch2001: linux-2.6-vm-silence-atomic-alloc-failures.patch
Patch2003: linux-2.6-vm-clear-unreclaimable.patch
Patch2004: linux-2.6-vm-debug.patch


#
# External drivers that are about to get accepted upstream
#

# patches 5000 to 6000 are new drivers included in Aurox
Patch5000: linux-2.6-ueagle-atm.patch

# Software Suspend 2
Patch5500: 100-suspend2-2.2-rc15-for-2.6.14.patch


#
# 10000 to 20000 is for stuff that has to come last due to the
# amount of drivers they touch. But only these should go here. 
# Not patches you're too lazy for to put in the proper place.
#
Patch10000: linux-2.6-compile-fixes.patch

# END OF PATCH DEFINITIONS

BuildRoot: %{_tmppath}/kernel-%{KVERREL}-root

%description 
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

%package devel
Summary: Development package for building kernel modules to match the kernel.
Group: System Environment/Kernel
AutoReqProv: no
Provides: kernel-devel-%{_target_cpu} = %{rpmversion}-%{release}
Prereq: /usr/sbin/hardlink, /usr/bin/find

%description devel
This package provides kernel headers and makefiles sufficient to build modules
against the kernel package.


%package doc
Summary: Various documentation bits found in the kernel source.
Group: Documentation

%description doc
This package contains documentation files from the kernel
source. Various bits of information about the Linux kernel and the
device drivers shipped with it are documented in these files. 

You'll want to install this package if you need a reference to the
options that can be passed to Linux kernel modules at load time.


%package smp
Summary: The Linux kernel compiled for SMP machines.

Group: System Environment/Kernel
Provides: kernel = %{version}
Provides: kernel-drm = 4.3.0
Provides: kernel-%{_target_cpu} = %{rpmversion}-%{release}smp
Provides: alsa-driver
Obsoletes: alsa-driver
Provides: kernel-smp-module-alsa
Provides: kernel-ntfs-smp
Provides: eagle-usb-kernel-smp
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
Conflicts: %{nptl_conflicts}
# upto and including kernel 2.4.9 rpms, the 4Gb+ kernel was called kernel-enterprise
# now that the smp kernel offers this capability, obsolete the old kernel
Obsoletes: kernel-enterprise < 2.4.10
# We can't let RPM do the dependencies automatic because it'll then pick up
# a correct but undesirable perl dependency from the module headers which
# isn't required for the kernel proper to function
AutoReqProv: no

%description smp
This package includes a SMP version of the Linux kernel. It is
required only on machines with two or more CPUs as well as machines with
hyperthreading technology.

Install the kernel-smp package if your machine uses two or more CPUs.

%package smp-devel
Summary: Development package for building kernel modules to match the SMP kernel.
Group: System Environment/Kernel
Provides: kernel-smp-devel-%{_target_cpu} = %{rpmversion}-%{release}
Provides: kernel-devel-%{_target_cpu} = %{rpmversion}-%{release}smp
Provides: kernel-devel = %{rpmversion}-%{release}smp
AutoReqProv: no
Prereq: /usr/sbin/hardlink, /usr/bin/find

%description smp-devel
This package provides kernel headers and makefiles sufficient to build modules
against the SMP kernel package.

%package xen0
Summary: The Linux kernel compiled for Xen guest0 VM operations

Group: System Environment/Kernel
Provides: kernel = %{version}
Provides: kernel-%{_target_cpu} = %{rpmversion}-%{release}xen0
Prereq: %{kernel_prereq}
Requires: xen
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
Conflicts: %{nptl_conflicts}
Conflicts: %{xen_conflicts}
# the xen0 kernel needs a newer mkinitrd than everything else right now
Conflicts: mkinitrd <= 4.2.0 
# We can't let RPM do the dependencies automatic because it'll then pick up
# a correct but undesirable perl dependency from the module headers which
# isn't required for the kernel proper to function
AutoReqProv: no

%description xen0
This package includes a version of the Linux kernel which
runs in Xen's guest0 VM and provides device services to
the unprivileged guests.

Install this package in your Xen guest0 environment.


%package xen0-devel
Summary: Development package for building kernel modules to match the kernel.
Group: System Environment/Kernel
AutoReqProv: no
Provides: kernel-xen0-devel-%{_target_cpu} = %{rpmversion}-%{release}
Provides: kernel-devel-%{_target_cpu} = %{rpmversion}-%{release}xen0
Provides: kernel-devel = %{rpmversion}-%{release}xen0
Prereq: /usr/sbin/hardlink, /usr/bin/find

%description xen0-devel
This package provides kernel headers and makefiles sufficient to build modules
against the kernel package.

%package xenU
Summary: The Linux kernel compiled for unprivileged Xen guest VMs

Group: System Environment/Kernel
Provides: kernel = %{version}
Provides: kernel-%{_target_cpu} = %{rpmversion}-%{release}xenU
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
Conflicts: %{nptl_conflicts}
Conflicts: %{xen_conflicts}
# We can't let RPM do the dependencies automatic because it'll then pick up
# a correct but undesirable perl dependency from the module headers which
# isn't required for the kernel proper to function
AutoReqProv: no

%description xenU
This package includes a version of the Linux kernel which
runs in Xen unprivileged guest VMs.  This should be installed
both inside the unprivileged guest (for the modules) and in
the guest0 domain.

%package xenU-devel
Summary: Development package for building kernel modules to match the kernel.
Group: System Environment/Kernel
AutoReqProv: no
Provides: kernel-xenU-devel-%{_target_cpu} = %{rpmversion}-%{release}
Provides: kernel-devel-%{_target_cpu} = %{rpmversion}-%{release}xenU
Provides: kernel-devel = %{rpmversion}-%{release}xenU
Prereq: /usr/sbin/hardlink, /usr/bin/find

%description xenU-devel
This package provides kernel headers and makefiles sufficient to build modules
against the kernel package.



%prep
if [ ! -d kernel-%{kversion}/vanilla ]; then
 # Ok, first time we do a make prep.
%setup -q -n %{name}-%{version} -c
 rm -f pax_global_header
 mv linux-%{kversion} vanilla
else
 # We already have a vanilla dir.
 cd kernel-%{kversion}
 rm -rf linux-%{kversion}
fi
cp -rl vanilla linux-%{kversion}
cd linux-%{kversion}

%patch1 -p1
#%patch2 -p1

#
# Patches 10 through 100 are meant for core subsystem upgrades
# 

#
# Patches to back out
#

#
# Architecture patches
#
%patch100 -p1

#
# x86(-64)
#
# Compile 686 kernels tuned for Pentium4.
%patch200 -p1
# Keep UP APIC off by default.
#%patch201 -p1
# add vidfail capability; 
# without this patch specifying a framebuffer on the kernel prompt would
# make the boot stop if there's no supported framebuffer device; this is bad
# for the installer cd that wants to automatically fall back to textmode
# in that case
%patch202 -p1
# Reboot through the BIOS on newer HP laptops
%patch203 -p1
# Workaround ATI 'clock going too fast' bug
%patch204 -p1


#
# Xen
#
%if %{includexen}
%patch700 -p1
%patch701 -p1
%patch702 -p1
%endif

#
# Patches 500 through 1000 are reserved for bugfixes to the core system
# and patches related to how RPMs are build
#


# This patch adds a "make nonint_oldconfig" which is non-interactive and
# also gives a list of missing options at the end. Useful for automated
# builds (as used in the buildsystem).
%patch800 -p1
# Warn if someone tries to build userspace using kernel headers
%patch801 -p1
# Fix qt config tool compilation on 64bit.
%patch802 -p1
# reference_discarded additions.
%patch803 -p1

# Exec shield 
%patch810 -p1

# Xen exec-shield bits
%if %{includexen}
%patch811 -p1
%endif

# Fix up the vdso.
%patch812 -p1

# Xen vDSO hack
%if %{includexen}
%patch813 -p1
%endif

# Write protect rodata
%patch814 -p1

#
# Patches 1000 to 5000 are reserved for bugfixes to drivers and filesystems
#



# Various low-impact patches to aid debugging.
%patch1011 -p1
%patch1012 -p1
%patch1013 -p1
%patch1014 -p1
%patch1015 -p1
%patch1016 -p1
%patch1017 -p1
%patch1018 -p1
%patch1019 -p1
%patch1020 -p1
%patch1021 -p1
%patch1022 -p1
%patch1023 -p1

#
# Make /dev/mem a need-to-know function 
#
%patch1050 -p1
%if %{includexen}
%patch1051 -p1
%endif

#
# /dev/crash driver for the crashdump analysis tool
#
%patch1060 -p1
%if %{includexen}
%patch1061 -p1
%endif

#
# Most^WAll users of sleep_on are broken; fix a bunch
#
%patch1070 -p1

# Adjust some defaults.
# Make CFQ default elevator again
%patch1080 -p1
# Bump up the number of recursive symlinks.
%patch1081 -p1
# Make optimise for size available without selecting CONFIG_EMBEDDED
%patch1082 -p1

#
# SCSI Bits.
#
# Enable Advansys driver
%patch1101 -p1
# Enable both new and old megaraid drivers.
%patch1102 -p1
# Add a pci table to advansys driver.
%patch1103 -p1
# fix usb storage oops
%patch1104 -p1

#
# Various upstream NFS/NFSD fixes.
#
%patch1200 -p1
# kNFSD: fixed '-p port' arg to rpc.nfsd and enables the defining proto versions and transports
%patch1201 -p1
# Fix badness in NFSD locking
%patch1202 -p1
# more NFS badness
%patch1203 -p1

# NIC driver fixes.
# New PCI ID for sundance driver.
%patch1301 -p1
# Fix rmmod lanai
%patch1302 -p1
# Acenic use after free
%patch1303 -p1
# sk98lin vpd fix
%patch1304 -p1

# disable pcmcia warnings
%patch1400 -p1

# Squashfs
%patch1450 -p1

# netdump bits
%patch1500 -p1
%patch1501 -p1
%patch1502 -p1
%patch1503 -p1
%patch1504 -p1
%patch1505 -p1

#
# Various SELinux fixes from 2.6.10rc
#

# Misc fixes
# Fix incorrect n_link in proc
%patch1600 -p1
# Make multimedia buttons on Dell Inspiron 8200 work.
%patch1610 -p1
# Canonicalise getxattr results.
%patch1620 -p1
# Add missing MODULE_VERSION tags to some modules.
%patch1630 -p1
# Silence silly debug message in cx88. (#168931)
%patch1650 -p1
# Fix suspend to sbp devices. (166452)
%patch1660 -p1
# The input layer spews crap no-one cares about.
%patch1670 -p1
# usb legacy workaround.
%patch1680 -p1
# Tickle the NMI whilst doing serial writes.
%patch1690 -p1
# Missing EXPORT_SYMBOL's
%patch1700 -p1
# Radeon on thinkpad backlight power-management goodness.
%patch1710 -p1
# Fix IDE locking bug.
%patch1720 -p1
# autofs4 looks up wrong path element when ghosting is enabled
%patch1730 -p1
# Fix maestro driver hangs
%patch1740 -p1
# 8139 suspend fix.
%patch1750 -p1
# Silence some SELinux msgs
%patch1751 -p1
# IRDA fix
%patch1753 -p1
# check condition in ide-scsi
%patch1754 -p1
# usbhid wireless security lock fix
%patch1755 -p1
# Fix infinite loop in rtnetlink
%patch1756 -p1
# silence w1 debug output
%patch1757 -p1
# power up pwc cameras by default
%patch1758 -p1
# stop kauditd from breaking suspend.
#%patch1759 -p1
# Increase timeout on firmware loader.
%patch1760 -p1
# Fix FPU corruption on return from S3
%patch1761 -p1
# Make PATA ports on Promise SATA work again.
%patch1771 -p1
# SELinux MLS compat.
%patch1782 -p1
# usbhid incorrectly claimed wacom penpartner tablet.
%patch1783 -p1
# Decrease stack usage in block layer
%patch1790 -p1

# ACPI patches.
# Enable EC burst
#%patch1800 -p1
# Change printk level of cutoff msg.
%patch1801 -p1
# Blacklist another 'No C2/C3 states' Thinkpad R40e BIOS.
%patch1802 -p1
# update to 2.6.15 era acpi
%patch1803 -p1
# Fix HT slowdown issue
%patch1804 -p1
# Increase owner_id limit
%patch1805 -p1

# Warn about obsolete functionality usage.
%patch1900 -p1
%patch1901 -p1
# Remove kernel-internal functionality that nothing external should use.
%patch1910 -p1

#
# VM related fixes.
#
# Extra debugging on OOM Kill.
%patch2000 -p1
# Silence GFP_ATOMIC failures.
%patch2001 -p1
# prevent OOM kills and page allocation failures under load.
%patch2003 -p1
# debug-fu
%patch2004 -p1

#
# Patches 5000 to 6000 are reserved for new drivers that are about to
# be merged upstream
#

# ueagle-atm driver for USB DSL modems, FIXME: breaks usbatm at the moment
%patch5000 -p1

# Software Suspend 2
%patch5500 -p1

#
# final stuff
#
%patch10000 -p1

#
# misc small stuff to make things compile or otherwise improve performance
#
#%patch10040 -p1


# END OF PATCH APPLICATIONS

cp %{SOURCE10} Documentation/

mkdir configs

cp -fv %{all_arch_configs} .


# now run oldconfig over all the config files
for i in *.config
do 
	mv $i .config 
	Arch=`head -1 .config | cut -b 3-`
%if %{includexen}
	make ARCH=$Arch nonint_oldconfig > /dev/null
%else
	if [ "$Arch" != "xen" ]; then
	  make ARCH=$Arch nonint_oldconfig > /dev/null
	fi
%endif
	echo "# $Arch" > configs/$i
	cat .config >> configs/$i 
done

# make sure the kernel has the sublevel we know it has. This looks weird
# but for -pre and -rc versions we need it since we only want to use
# the higher version when the final kernel is released.
perl -p -i -e "s/^SUBLEVEL.*/SUBLEVEL = %{sublevel}/" Makefile
perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -prep/" Makefile

# get rid of unwanted files resulting from patch fuzz
find . -name "*.orig" -exec rm -fv {} \;
find . -name "*~" -exec rm -fv {} \;

###
### build
###
%build

#
# Create gpg keys for signing the modules
#

%if %{signmodules}
gpg --homedir . --batch --gen-key %{SOURCE11}  
gpg --homedir . --export --keyring ./kernel.pub Red > extract.pub 
make linux-%{kversion}/scripts/bin2c
linux-%{kversion}/scripts/bin2c ksign_def_public_key __initdata < extract.pub > linux-%{kversion}/crypto/signature/key.h
%endif

cd linux-%{kversion}



BuildKernel() {

    # Pick the right config file for the kernel we're building
    if [ -n "$1" ] ; then
	Config=kernel-%{kversion}-%{_target_cpu}-$1.config
	DevelDir=/usr/src/kernels/%{KVERREL}-$1-%{_target_cpu}
	DevelLink=/usr/src/kernels/%{KVERREL}$1-%{_target_cpu}
    else
	Config=kernel-%{kversion}-%{_target_cpu}.config
	DevelDir=/usr/src/kernels/%{KVERREL}-%{_target_cpu}
	DevelLink=
    fi

    KernelVer=%{version}-%{release}$1
    echo BUILDING A KERNEL FOR $1 %{_target_cpu}...

    # make sure EXTRAVERSION says what we want it to say
    perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -%{release}$1/" Makefile

    # and now to start the build process

    make -s mrproper
    cp configs/$Config .config

    Arch=`head -1 .config | cut -b 3-`
    echo USING ARCH=$Arch

    make -s ARCH=$Arch nonint_oldconfig > /dev/null
    make -s ARCH=$Arch include/linux/version.h 

    make -s ARCH=$Arch %{?_smp_mflags} %{make_target}
    make -s ARCH=$Arch %{?_smp_mflags} modules || exit 1
    make ARCH=$Arch buildcheck
    
    # Start installing the results

%if "%{_enable_debug_packages}" == "1"
    mkdir -p $RPM_BUILD_ROOT/usr/lib/debug/boot
%endif
    mkdir -p $RPM_BUILD_ROOT/%{image_install_path}
    install -m 644 .config $RPM_BUILD_ROOT/boot/config-$KernelVer
    install -m 644 System.map $RPM_BUILD_ROOT/boot/System.map-$KernelVer
    cp arch/$Arch/boot/bzImage $RPM_BUILD_ROOT/%{image_install_path}/vmlinuz-$KernelVer
	if [ -f arch/$Arch/boot/zImage.stub ]; then
      cp arch/$Arch/boot/zImage.stub $RPM_BUILD_ROOT/%{image_install_path}/zImage.stub-$KernelVer || :
	fi

    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer
    make -s ARCH=$Arch INSTALL_MOD_PATH=$RPM_BUILD_ROOT modules_install KERNELRELEASE=$KernelVer
 
    # And save the headers/makefiles etc for building modules against
    #
    # This all looks scary, but the end result is supposed to be:
    # * all arch relevant include/ files
    # * all Makefile/Kconfig files
    # * all script/ files 

    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/source
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    (cd $RPM_BUILD_ROOT/lib/modules/$KernelVer ; ln -s build source)
    # first copy everything
    cp --parents `find  -type f -name "Makefile*" -o -name "Kconfig*"` $RPM_BUILD_ROOT/lib/modules/$KernelVer/build 
    cp Module.symvers $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    # then drop all but the needed Makefiles/Kconfig files
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Documentation
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cp arch/%{_arch}/kernel/asm-offsets.s $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch}/kernel || :
    cp .config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    if [ -d arch/%{_arch}/scripts ]; then
      cp -a arch/%{_arch}/scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch} || :
    fi
    if [ -f arch/%{_arch}/*lds ]; then
      cp -a arch/%{_arch}/*lds $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch}/ || :
    fi
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*.o
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*/*.o
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cp -a drivers/media/dvb/frontends/*.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/drivers/media/dvb/frontends
    cp -a drivers/media/dvb/dvb-core/*.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/drivers/media/dvb/dvb-core
    cd include
    cp -a acpi config linux math-emu media net pcmcia rxrpc scsi sound video asm asm-generic $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
%if %{buildxen}
    cp -a asm-xen $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
%endif
    cp -a `readlink asm` $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    if [ "$Arch" = "x86_64" ]; then
      cp -a asm-i386 $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    fi
    if [ "$Arch" = "ppc64" ]; then
      cp -a asm-ppc $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    fi
    if [ "$Arch" = "ppc" -o "$Arch" = "ppc64" ]; then
      cp -a asm-powerpc $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
      mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/$Arch/include
      ln -sf ../../../include/asm-powerpc $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/$Arch/include/asm
    fi
    # Make sure the Makefile and version.h have a matching timestamp so that
    # external modules can be built
    touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Makefile $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/linux/version.h
    touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/.config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/linux/autoconf.h
    cd .. 

    #
    # save the vmlinux file for kernel debugging into the kernel-debuginfo rpm
    #
%if "%{_enable_debug_packages}" == "1"
    mkdir -p $RPM_BUILD_ROOT/usr/lib/debug/lib/modules/$KernelVer
    cp vmlinux $RPM_BUILD_ROOT/usr/lib/debug/lib/modules/$KernelVer
%endif

    # gpg sign the modules
%if %{signmodules}
    gcc -o scripts/modsign/mod-extract scripts/modsign/mod-extract.c -Wall
	KEYFLAGS="--no-default-keyring --homedir .." 
	KEYFLAGS="$KEYFLAGS --secret-keyring ../kernel.sec" 
	KEYFLAGS="$KEYFLAGS --keyring ../kernel.pub" 
	export KEYFLAGS 
    for i in ` find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name "*.ko" -type f`
	do
		sh ./scripts/modsign/modsign.sh $i Red
        mv -f $i.signed $i
    done
	unset KEYFLAGS
%endif

    # mark modules executable so that strip-to-file can strip them
    find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name "*.ko" -type f  | xargs chmod u+x

    # detect missing or incorrect license tags
    for i in `find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name "*.ko" `
	do
		echo -n "$i " 
		/sbin/modinfo -l $i >> modinfo
	done
    cat modinfo |\
		grep -v "^GPL" |
		grep -v "^Dual BSD/GPL" |\
		grep -v "^Dual MPL/GPL" |\
		grep -v "^GPL and additional rights" |\
		grep -v "^GPL v2" && exit 1 
    rm -f modinfo
    # remove files that will be auto generated by depmod at rpm -i time
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.*

    # Move the devel headers out of the root file system
    mkdir -p $RPM_BUILD_ROOT/usr/src/kernels
    mv $RPM_BUILD_ROOT/lib/modules/$KernelVer/build $RPM_BUILD_ROOT/$DevelDir
    ln -sf ../../..$DevelDir $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    [ -z "$DevelLink" ] || ln -sf `basename $DevelDir` $RPM_BUILD_ROOT/$DevelLink
}

###
# DO it...
###

# prepare directories
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/boot

%if %{buildup}
BuildKernel
%endif

%if %{buildsmp}
BuildKernel smp
%endif

%if %{buildxen}
BuildKernel xen0
BuildKernel xenU
%endif


###
### install
###

%install

cd linux-%{kversion}

%if %{buildxen}
mkdir -p $RPM_BUILD_ROOT/etc/ld.so.conf.d
rm -f $RPM_BUILD_ROOT/etc/ld.so.conf.d/kernelcap-%{KVERREL}.conf
cat > $RPM_BUILD_ROOT/etc/ld.so.conf.d/kernelcap-%{KVERREL}.conf <<\EOF
# This directive teaches ldconfig to search in nosegneg subdirectories
# and cache the DSOs there with extra bit 0 set in their hwcap match
# fields.  In Xen guest kernels, the vDSO tells the dynamic linker to
# search in nosegneg subdirectories and to match this extra hwcap bit
# in the ld.so.cache file.
hwcap 0 nosegneg
EOF
chmod 444 $RPM_BUILD_ROOT/etc/ld.so.conf.d/kernelcap-%{KVERREL}.conf
%endif

%if %{builddoc}
mkdir -p $RPM_BUILD_ROOT/usr/share/doc/kernel-doc-%{kversion}/Documentation

# sometimes non-world-readable files sneak into the kernel source tree
chmod -R a+r *
# copy the source over
tar cf - Documentation | tar xf - -C $RPM_BUILD_ROOT/usr/share/doc/kernel-doc-%{kversion}
%endif

###
### clean
###

%clean
rm -rf $RPM_BUILD_ROOT

###
### scripts
###

# load the loop module for upgrades...in case the old modules get removed we have
# loopback in the kernel so that mkinitrd will work.
%pre 
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
exit 0

%pre smp
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
exit 0

%post 
[ ! -x /usr/sbin/module_upgrade ] || /usr/sbin/module_upgrade
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --package kernel --mkinitrd --depmod --install %{KVERREL}
# remove hdX=ide-scsi when upgrading from 2.4 kernels, booty doesn't handle this correctly
[ -x /bin/sed ] && [ -f /boot/grub/grub.conf ] && /bin/sed -i -e "s/\(vmlinuz-%{version}-%{release}.*\) hd.=ide-scsi\(.*\)/\1\2/" /boot/grub/grub.conf

%post devel
if [ -x /usr/sbin/hardlink ] ; then
pushd /usr/src/kernels/%{KVERREL}-%{_target_cpu} > /dev/null
/usr/bin/find . -type f | while read f; do hardlink -c /usr/src/kernels/*FC*/$f $f ; done
popd > /dev/null
fi

%post smp
[ ! -x /usr/sbin/module_upgrade ] || /usr/sbin/module_upgrade
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --package kernel-smp --mkinitrd --depmod --install %{KVERREL}smp
# remove hdX=ide-scsi when upgrading from 2.4 kernels, booty doesn't handle this correctly
[ -x /bin/sed ] && [ -f /boot/grub/grub.conf ] && /bin/sed -i -e "s/\(vmlinuz-%{version}-%{release}.*\) hd.=ide-scsi\(.*\)/\1\2/" /boot/grub/grub.conf

%post smp-devel
if [ -x /usr/sbin/hardlink ] ; then
pushd /usr/src/kernels/%{KVERREL}-smp-%{_target_cpu} > /dev/null
/usr/bin/find . -type f | while read f; do hardlink -c /usr/src/kernels/*FC*/$f $f ; done
popd > /dev/null
fi

%post xen0
[ ! -x /usr/sbin/module_upgrade ] || /usr/sbin/module_upgrade
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --package kernel-xen0 --mkinitrd --depmod --install --multiboot %{KVERREL}xen0
[ ! -x /sbin/ldconfig ] || /sbin/ldconfig -X

%post xen0-devel
if [ -x /usr/sbin/hardlink ] ; then
pushd /usr/src/kernels/%{KVERREL}-xen0-%{_target_cpu} > /dev/null
/usr/bin/find . -type f | while read f; do hardlink -c /usr/src/kernels/*FC*/$f $f ; done
popd > /dev/null
fi

%post xenU
[ ! -x /usr/sbin/module_upgrade ] || /usr/sbin/module_upgrade
[ ! -x /sbin/ldconfig ] || /sbin/ldconfig -X

%post xenU-devel
if [ -x /usr/sbin/hardlink ] ; then
pushd /usr/src/kernels/%{KVERREL}-xenU-%{_target_cpu} > /dev/null
/usr/bin/find . -type f | while read f; do hardlink -c /usr/src/kernels/*FC*/$f $f ; done
popd > /dev/null
fi


%preun 
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}

%preun smp
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}smp

%preun xen0
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}xen0

%preun xenU
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --rmmoddep --remove %{KVERREL}xenU


###
### file lists
###

%if %{buildup}
%files 
%defattr(-,root,root)
/%{image_install_path}/vmlinuz-%{KVERREL}
/boot/System.map-%{KVERREL}
/boot/config-%{KVERREL}
%dir /lib/modules/%{KVERREL}
/lib/modules/%{KVERREL}/kernel
/lib/modules/%{KVERREL}/build
/lib/modules/%{KVERREL}/source

%files devel
%defattr(-,root,root)
%verify(not mtime) /usr/src/kernels/%{KVERREL}-%{_target_cpu}
%endif

%if %{buildsmp}
%files smp
%defattr(-,root,root)
/%{image_install_path}/vmlinuz-%{KVERREL}smp
/boot/System.map-%{KVERREL}smp
/boot/config-%{KVERREL}smp
%dir /lib/modules/%{KVERREL}smp
/lib/modules/%{KVERREL}smp/kernel
/lib/modules/%{KVERREL}smp/build
/lib/modules/%{KVERREL}smp/source

%files smp-devel
%defattr(-,root,root)
%verify(not mtime) /usr/src/kernels/%{KVERREL}-smp-%{_target_cpu}
/usr/src/kernels/%{KVERREL}smp-%{_target_cpu}
%endif

%if %{buildxen}
%files xen0
%defattr(-,root,root)
/%{image_install_path}/vmlinuz-%{KVERREL}xen0
/boot/System.map-%{KVERREL}xen0
/boot/config-%{KVERREL}xen0
%dir /lib/modules/%{KVERREL}xen0
/lib/modules/%{KVERREL}xen0/kernel
%verify(not mtime) /lib/modules/%{KVERREL}xen0/build
/lib/modules/%{KVERREL}xen0/source
/etc/ld.so.conf.d/kernelcap-%{KVERREL}.conf

%files xen0-devel
%defattr(-,root,root)
%verify(not mtime) /usr/src/kernels/%{KVERREL}-xen0-%{_target_cpu}
/usr/src/kernels/%{KVERREL}xen0-%{_target_cpu}

%files xenU
%defattr(-,root,root)
/%{image_install_path}/vmlinuz-%{KVERREL}xenU
/boot/System.map-%{KVERREL}xenU
/boot/config-%{KVERREL}xenU
%dir /lib/modules/%{KVERREL}xenU
/lib/modules/%{KVERREL}xenU/kernel
%verify(not mtime) /lib/modules/%{KVERREL}xenU/build
/lib/modules/%{KVERREL}xenU/source
/etc/ld.so.conf.d/kernelcap-%{KVERREL}.conf

%files xenU-devel
%defattr(-,root,root)
%verify(not mtime) /usr/src/kernels/%{KVERREL}-xenU-%{_target_cpu}
/usr/src/kernels/%{KVERREL}xenU-%{_target_cpu}
%endif


# only some architecture builds need kernel-doc

%if %{builddoc}
%files doc
%defattr(-,root,root)
%{_datadir}/doc/kernel-doc-%{kversion}/Documentation/*
%dir %{_datadir}/doc/kernel-doc-%{kversion}/Documentation
%dir %{_datadir}/doc/kernel-doc-%{kversion}
%endif

%changelog
* Mon Jan 30 2006 Karol Kozimor <kkozimor@aurox.org> 2.6.14-11.1.aur.2
- Add ueagle 1.0d1 for USB DSL modems.
- Add squashfs 2.2-r2.

* Thu Jan 12 2006 Karol Kozimor <kkozimor@aurox.org> 2.6.14-11.1.aur.1
- 2.6.14.6.
- Suspend2 2.2-rc15.

* Mon Aug 08 2005 Karol Kozimor <kkozimor@aurox.org> 2.6.12-11.0.aur.2
- 2.6.12.4.
- Fix ipw2200 build.
- Fix auditd suspend.

* Thu Jul 28 2005 Karol Kozimor <kkozimor@aurox.org> 2.6.12-11.0.aur.1
- Rebase against 2.6.12.
- 2.6.12.3.
- Software Suspend 2.1.9.5.
- ipw2100 1.1.0 and ipw2200 1.0.1.

* Tue Apr 26 2005 Aurox Team <aurox@aurox.org> 2.6.10-10.3.aur.2
- Backport selected patches from 2.6.11.7 (mainly security fixes).

* Wed Mar 09 2005 Aurox Team <aurox@aurox.org> 2.6.10-10.3.aur.1
- 2.6.10.
- Rebase to 2.6.10-ac12.
- Remove stale / already applied patches.
- Minor updates to other patches.
- Update swsusp2 to 2.1.7 for 2.6.10.

* Wed Feb 09 2005 Aurox Team <aurox@aurox.org> 2.6.9-10.2.aur.2
- Update ipw2100 to 1.0.3 and ipw2200 to 1.0.0 (the latter needs 2.2 firmware).
- Add more bits from 2.6.10-ac series (January security fixes).
- Fix nForce2 APIC hangs.
- Restore old megaraid module.
- Fix ext3 umount hang.
- Rebase against 2.6.9-ac16, this fixes a number of bugs, including a nasty one in the OOM code.

* Wed Feb 02 2005 Aurox Team <aurox@aurox.org> 2.6.9-10.2.aur.1
- Merge bits from -ac kernels.

* Thu Nov 11 2004 Aurox Team <aurox@aurox.org> 2.6.9-10.1.aur.4
- Update swsusp2 to 2.1.5.
- Fix binfmt_elf bug.
- Add Intel PRO/Wireless 2200 802.11bg Driver for Linux 0.12.
- Fold the ipw2x00 drivers into a single patch.
- Update to swsusp 2.1.4.
- Readd hdX=ide-scsi removal.
- Fix incorrect Mt Rainier detection.
- Fix i8xx_tco watchdog causing reboots.
- Export __VMALLOC_RESERVE to make nVidia modules compile.
- Update DVD+RW / packet writing patches.
- Update swsusp2 to 2.1.
- Update ipw2100 to 0.56 (needs v1.3 firmware).
- Update external patches.
- Update exec shield patches.
- Rebase against 2.6.9.
- Remove ide-scsi hacks, booty should handle this by now.
- Upgrade to ipw2100-0.51 (ipw2100-firmware-1.2 needed)
- obsoletes: kernel-module-alsa, kernel-module-ntfs
- SMP/UP separation take two, .configs modified.
- Separate SMP and UP builds, take one.
- i8x0 DRM fix
- Remove hdX=ide-scsi leftover in postinstall
- Fix oops on Centrino
- Add swsusp2 2.6.7-rev4/2.0.0.90
- Add ipw2100-0.49 to the build
- Security fixes
- Fix denial of service in tcp_find_option()
- Merge ALSA CVS as of 2004-05-31 (1.0.5a)
- Compile for Athlon
- Remove SCSI debug
- Disable vdso in exec-shield
- Add i586
- upgrade to 2.6.7-final
- readd exec-shield-nx-2.6.7-A0
- modify kernel.spec to account for kbuild changes: single invocation of make
- drop linux-2.6.7-compile.patch, not needed
- remove bk patch; build 2.6.7-rc3
- update to 2.6.7-rc3-bk6
- add packet writing patch for CD-RW
- remove references to use_nx from exec-shield patch
- adapt exec-shield patch
- build 2.6.7-rc3-bk5
- disable PM_DISK
- Enable BLK_DEV_OFFBOARD and ide-scsi modules
- Remove outdated config options
- most of the compile patch removed (not needed?)
- remove exec-shield for this build until it is merged with our changes
- update exec-shield using exec-shield-on-nx-2.6.7-rc2-bk2-A9
- Update to patch-2.6.7-rc2-bk7
- Enable PM_DISK (the new software suspend fork)
- Enable two more sound drivers modules: SND_SERIAL_U16550 and SND_WAVEFRONT
- set SMB_NLS_DEFAULT to "cp437"
- update config options in 2.6.7-rc2, enabling all Gigabit drivers
- no need to patch ALSA
- update to 2.6.7-rc2
- rebuild as preemptible kernel (CONFIG_PREEMPT=y)
- rebuild with SECURITY_CAPABILITIES set to 'm'
- build doc and source too
- build with fixed exec-shield and latest ALSA
- fix exec shield patch
- update config for 2.6.7-rc1
- make exec shield patch apply on 2.6.7-rc1
- update to 2.6.7-rc1
- enable NTFS RW suppport
- update to bk8 snapshot
- update ASLA drivers to post-1.0.4 CVS - from mm4 patch set
- rebuild for Aurox 10
- remove patches not applied on Aurox
- use exec-shield updated for 2.6.6; remove offending arch/s390/kernel/binfmt_elf32.c
- import kernel 2.6

* Sat May 08 2004 Arjan van de Ven <arjanv@redhat.com>
- fix non-booting on Transmeta cpus (Peter Anvin)
- fix count leak in message queues

* Fri May 07 2004 Arjan van de Ven <arjanv@redhat.com>
- more ide cache flush work
- patch from scsi-bk to fix sd refcounting

* Thu May 06 2004 Arjan van de Ven <arjanv@redhat.com>
- some more ide cache flush fixes 

* Wed May 05 2004 Arjan van de Ven <arjanv@redhat.com>
- fix bug 122504
- convert b44 to ethtool ops (jgarzik)
- make IDE do a cache-flush on shutdown (me/Alan)

* Tue May 04 2004 Arjan van de Ven <arjanv@redhat.com>
- work around i810/i830 DRM issue

* Fri Apr 30 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.6-rc3-bk1
- make amd64 boot again
- fix vm86-vs-4g4g interaction (Ingo)

* Thu Apr 22 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.6-rc2
 
* Tue Apr 20 2004 Arjan van de Ven <arjanv@redhat.com>
- add the ext3 online resize patch

* Mon Apr 19 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.6-rc1-bk3
- add the objrmap vm from the -mm tree; it needs testing

* Thu Apr 15 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.5-bk2
- disable DISCONTIGMEM on ia64 for performance
- fix sleep_on use in reiserfs (Chris Mason)

* Tue Apr 13 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.5-mc4
- reenable sg driver for scsi tape changers and such
- the sk98lin driver oopses on module unload, preven that

* Mon Apr 12 2004 Arjan van de Ven <arjanv@redhat.com>
- fix "bad pmd" bug with patch from Ingo

* Fri Apr 09 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.5-mc3
- finish up the -mc2 merge
- latest 4g/4g patch from Ingo
- latest execshield patch from Ingo
- fix a few framebuffer bugs

* Thu Apr 08 2004 Arjan van de Ven <arjanv@redhat.com>
- first attempt at a 2.6.5-mc2 merge

* Thu Apr 08 2004 Dave Jones <davej@redhat.com>
- Add in missing SiS AGP fix.

* Tue Apr 06 2004 Dave Jones <davej@redhat.com>
- More agpgart fixes.

* Fri Apr 02 2004 Arjan van de Ven <arjanv@redhat.com>
- fix another 4g/4g-vs-resume bug

* Tue Mar 30 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.5-rc3
- fix PCI posting bug in i830 DRM

* Mon Mar 29 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.5-rc2-bk8

* Mon Mar 29 2004 Dave Jones <davej@redhat.com>
- Include latest agpgart fixes.

* Thu Mar 25 2004 Arjan van de Ven <arjanv@redhat.com>
- more DRM fixes
- add the fsync patches from akpm

* Tue Mar 23 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.5-rc2-bk3
- fix direct userspace memory access in i830 drm driver

* Mon Mar 22 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.5-rc2-bk2
- some stackbloat reductions from Dave and me

* Sat Mar 20 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.5-rc2

* Tue Mar 16 2004 Dave Jones <davej@redhat.com>
- 2.6.5-rc1

* Mon Mar 15 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.4-bk3
- fix oops in toshiba_acpi (Barry K. Nathan)

* Sat Mar 13 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.4-bk2 merge 

* Thu Mar 11 2004 Arjan van de Ven <arjanv@redhat.com>
- renable sonypi driver that was off accidentally
- 2.6.4-final 
- fix the oops on alsa module unloads

* Wed Mar 10 2004 Arjan van de Ven <arjanv@redhat.com>
- add ppc64/iseries, ppc32 (powermac/ibook) and ia64 architectures
- 2.6.4-rc3 

* Tue Mar 09 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.4-rc2-bk5
- fix nfs-vs-selinux issue
- fix typo in URL as per #117849

* Mon Mar 08 2004 Arjan van de Ven <arjanv@redhat.com>
- fix race in lp.c (#117710)
- 2.6.4-rc2-bk3
- attempt to fix S3 suspend-to-ram with 4g/4g split

* Sat Mar 06 2004 Arjan van de Ven <arjanv@redhat.com>
- fix reiserfs
- set HZ to 1000 again for some tests

* Wed Feb 25 2004 Arjan van de Ven <arjanv@redhat.com>
- merge back a bunch of fedora fixes
- disable audit

* Tue Feb 24 2004 Arjan van de Ven <arjanv@redhat.com>
- audit bugfixes
- update tux to a working version
- 2.6.3-bk5 merge

* Fri Feb 20 2004 Arjan van de Ven <arjanv@redhat.com>
- re-add and enable the Auditing patch
- switch several cpufreq modules to built in since detecting in userspace
  which to use is unpleasant

* Thu Jul 03 2003 Arjan van de Ven <arjanv@redhat.com>
- 2.6 start

